summaryrefslogtreecommitdiffstats
path: root/kalarm/sounddlg.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-16 20:17:18 +0000
commitf4fae92b6768541e2952173c3d4b09040f95bf7e (patch)
treed8c5d93232235cd635f3310b4d95490df181ba2d /kalarm/sounddlg.cpp
parent125c0a08265b75a133644d3b55f47e37c919f45d (diff)
downloadtdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.tar.gz
tdepim-f4fae92b6768541e2952173c3d4b09040f95bf7e.zip
Moved kpilot from kdepim to applications, as the core Trinity libraries should not contain hardware-dependent software
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1221127 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/sounddlg.cpp')
-rw-r--r--kalarm/sounddlg.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/kalarm/sounddlg.cpp b/kalarm/sounddlg.cpp
index 2df7542b..691ba936 100644
--- a/kalarm/sounddlg.cpp
+++ b/kalarm/sounddlg.cpp
@@ -78,14 +78,14 @@ SoundDlg::SoundDlg(const TQString& file, float volume, float fadeVolume, int fad
{
TQWidget* page = new TQWidget(this);
setMainWidget(page);
- TQVBoxLayout* layout = new TQVBoxLayout(page, 0, spacingHint());
+ TQVBoxLayout* tqlayout = new TQVBoxLayout(page, 0, spacingHint());
// File play button
TQHBox* box = new TQHBox(page);
- layout->addWidget(box);
+ tqlayout->addWidget(box);
mFilePlay = new TQPushButton(box);
mFilePlay->setPixmap(SmallIcon("player_play"));
- mFilePlay->setFixedSize(mFilePlay->sizeHint());
+ mFilePlay->setFixedSize(mFilePlay->tqsizeHint());
connect(mFilePlay, TQT_SIGNAL(clicked()), TQT_SLOT(playSound()));
TQToolTip::add(mFilePlay, i18n("Test the sound"));
TQWhatsThis::add(mFilePlay, i18n("Play the selected sound file."));
@@ -98,36 +98,36 @@ SoundDlg::SoundDlg(const TQString& file, float volume, float fadeVolume, int fad
// File browse button
mFileBrowseButton = new PushButton(box);
mFileBrowseButton->setPixmap(SmallIcon("fileopen"));
- mFileBrowseButton->setFixedSize(mFileBrowseButton->sizeHint());
+ mFileBrowseButton->setFixedSize(mFileBrowseButton->tqsizeHint());
connect(mFileBrowseButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotPickFile()));
TQToolTip::add(mFileBrowseButton, i18n("Choose a file"));
TQWhatsThis::add(mFileBrowseButton, i18n("Select a sound file to play."));
// Sound repetition checkbox
mRepeatCheckbox = new CheckBox(i18n_p_Repeat(), page);
- mRepeatCheckbox->setFixedSize(mRepeatCheckbox->sizeHint());
+ mRepeatCheckbox->setFixedSize(mRepeatCheckbox->tqsizeHint());
TQWhatsThis::add(mRepeatCheckbox,
i18n("If checked, the sound file will be played repeatedly for as long as the message is displayed."));
- layout->addWidget(mRepeatCheckbox);
+ tqlayout->addWidget(mRepeatCheckbox);
// Volume
TQGroupBox* group = new TQGroupBox(i18n("Volume"), page);
- layout->addWidget(group);
+ tqlayout->addWidget(group);
TQGridLayout* grid = new TQGridLayout(group, 4, 3, marginHint(), spacingHint());
grid->addRowSpacing(0, fontMetrics().height() - marginHint() + spacingHint());
grid->setColStretch(2, 1);
int indentWidth = 3 * KDialog::spacingHint();
grid->addColSpacing(0, indentWidth);
grid->addColSpacing(1, indentWidth);
- // Get alignment to use in TQGridLayout (AlignAuto doesn't work correctly there)
- int alignment = TQApplication::reverseLayout() ? Qt::AlignRight : Qt::AlignLeft;
+ // Get tqalignment to use in TQGridLayout (AlignAuto doesn't work correctly there)
+ int tqalignment = TQApplication::reverseLayout() ? Qt::AlignRight : Qt::AlignLeft;
// 'Set volume' checkbox
box = new TQHBox(group);
box->setSpacing(spacingHint());
grid->addMultiCellWidget(box, 1, 1, 0, 2);
mVolumeCheckbox = new CheckBox(i18n_v_SetVolume(), box);
- mVolumeCheckbox->setFixedSize(mVolumeCheckbox->sizeHint());
+ mVolumeCheckbox->setFixedSize(mVolumeCheckbox->tqsizeHint());
connect(mVolumeCheckbox, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotVolumeToggled(bool)));
TQWhatsThis::add(mVolumeCheckbox,
i18n("Select to choose the volume for playing the sound file."));
@@ -136,30 +136,30 @@ SoundDlg::SoundDlg(const TQString& file, float volume, float fadeVolume, int fad
mVolumeSlider = new Slider(0, 100, 10, 0, Qt::Horizontal, box);
mVolumeSlider->setTickmarks(TQSlider::Below);
mVolumeSlider->setTickInterval(10);
- mVolumeSlider->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
+ mVolumeSlider->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
TQWhatsThis::add(mVolumeSlider, i18n("Choose the volume for playing the sound file."));
mVolumeCheckbox->setFocusWidget(mVolumeSlider);
// Fade checkbox
mFadeCheckbox = new CheckBox(i18n("Fade"), group);
- mFadeCheckbox->setFixedSize(mFadeCheckbox->sizeHint());
+ mFadeCheckbox->setFixedSize(mFadeCheckbox->tqsizeHint());
connect(mFadeCheckbox, TQT_SIGNAL(toggled(bool)), TQT_SLOT(slotFadeToggled(bool)));
TQWhatsThis::add(mFadeCheckbox,
i18n("Select to fade the volume when the sound file first starts to play."));
- grid->addMultiCellWidget(mFadeCheckbox, 2, 2, 1, 2, alignment);
+ grid->addMultiCellWidget(mFadeCheckbox, 2, 2, 1, 2, tqalignment);
// Fade time
mFadeBox = new TQHBox(group);
mFadeBox->setSpacing(spacingHint());
- grid->addWidget(mFadeBox, 3, 2, alignment);
+ grid->addWidget(mFadeBox, 3, 2, tqalignment);
TQLabel* label = new TQLabel(i18n("Time period over which to fade the sound", "Fade time:"), mFadeBox);
- label->setFixedSize(label->sizeHint());
+ label->setFixedSize(label->tqsizeHint());
mFadeTime = new SpinBox(1, 999, 1, mFadeBox);
mFadeTime->setLineShiftStep(10);
- mFadeTime->setFixedSize(mFadeTime->sizeHint());
+ mFadeTime->setFixedSize(mFadeTime->tqsizeHint());
label->setBuddy(mFadeTime);
label = new TQLabel(i18n("seconds"), mFadeBox);
- label->setFixedSize(label->sizeHint());
+ label->setFixedSize(label->tqsizeHint());
TQWhatsThis::add(mFadeBox, i18n("Enter how many seconds to fade the sound before reaching the set volume."));
// Fade slider
@@ -167,11 +167,11 @@ SoundDlg::SoundDlg(const TQString& file, float volume, float fadeVolume, int fad
mFadeVolumeBox->setSpacing(spacingHint());
grid->addWidget(mFadeVolumeBox, 4, 2);
label = new TQLabel(i18n("Initial volume:"), mFadeVolumeBox);
- label->setFixedSize(label->sizeHint());
+ label->setFixedSize(label->tqsizeHint());
mFadeSlider = new Slider(0, 100, 10, 0, Qt::Horizontal, mFadeVolumeBox);
mFadeSlider->setTickmarks(TQSlider::Below);
mFadeSlider->setTickInterval(10);
- mFadeSlider->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
+ mFadeSlider->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed));
label->setBuddy(mFadeSlider);
TQWhatsThis::add(mFadeVolumeBox, i18n("Choose the initial volume for playing the sound file."));
@@ -412,7 +412,7 @@ bool SoundDlg::checkFile()
#endif
{
// It's a relative path.
- // Find the first sound resource that contains files.
+ // Find the first sound resource that tqcontains files.
TQStringList soundDirs = KGlobal::dirs()->resourceDirs("sound");
if (!soundDirs.isEmpty())
{